# Changelog

## [0.0.4](https://github.com/czbiohub-sf/grassp/compare/v0.0.3...v0.0.4) (2026-02-09)


### Bug Fixes

* bump version ([8867130](https://github.com/czbiohub-sf/grassp/commit/886713043206d580727e2a7823f7656dccc7e28f))
* fetch tags in build ([d06132f](https://github.com/czbiohub-sf/grassp/commit/d06132f03748c888ec1f36915ac90e24c2953e93))

## [0.0.3](https://github.com/czbiohub-sf/grassp/compare/v0.0.3...v0.0.3) (2026-02-09)


### Bug Fixes

* fetch tags in build ([d06132f](https://github.com/czbiohub-sf/grassp/commit/d06132f03748c888ec1f36915ac90e24c2953e93))

## 0.0.3 (2026-02-09)


### Features

* add documentation for new grassp functions ([bd215f7](https://github.com/czbiohub-sf/grassp/commit/bd215f75862be936d1a36531e4441633872bc727))
* add enhanced knn annotation ([280fec1](https://github.com/czbiohub-sf/grassp/commit/280fec1878d140056411072bf95cf76b86a6720c))
* add function to remove cRAP proteins ([32bf4a6](https://github.com/czbiohub-sf/grassp/commit/32bf4a6285af60293ae01d499eee33cb6ac4b710))
* add knn-scoring and plotting ([e9dccb9](https://github.com/czbiohub-sf/grassp/commit/e9dccb979725cb0bff90fb681498967c18aa8ce8))
* add marker_profiles function ([51cfe6b](https://github.com/czbiohub-sf/grassp/commit/51cfe6b126e21bca1e7b290853bff4c5293c1b94))
* add neighbors wrapper with layer argument ([31d8d2d](https://github.com/czbiohub-sf/grassp/commit/31d8d2ddcb2866384b0b28a94b62f7e808697c0e))
* add plotting function for markers ([2edaab6](https://github.com/czbiohub-sf/grassp/commit/2edaab645a3735638d0ad680705cf572e5837c98))
* add Release Please + PyPI publishing workflow ([#17](https://github.com/czbiohub-sf/grassp/issues/17)) ([327408b](https://github.com/czbiohub-sf/grassp/commit/327408b91acbacf4cf780c10d8e5934d00da4b5d))
* add replicate cv function ([0612e6f](https://github.com/czbiohub-sf/grassp/commit/0612e6fe54d2f4a0593408beaaac0ca7ead4fb0f))
* add_external_validation_markers function ([2867f22](https://github.com/czbiohub-sf/grassp/commit/2867f22203acf3cac40483be985ba25d88533d2b))


### Bug Fixes

* add neighbors and knn_score to init ([f26eddc](https://github.com/czbiohub-sf/grassp/commit/f26eddc7a4401e1bec6056ab3c109f454023bb84))
* consistent compartment colors for knn_annotation ([287920b](https://github.com/czbiohub-sf/grassp/commit/287920b4dd1a5ddb95da977e899b4f268e36faea))
* make colors less similar ([359762e](https://github.com/czbiohub-sf/grassp/commit/359762e18f80f71f94ae738aea3bbdddcd074ef8))
* preprocessing intregration tests ([d82bbba](https://github.com/czbiohub-sf/grassp/commit/d82bbba97535491eee3e7d813ad2e71c90b9988b))
* read prolocdata bug ([46c0c56](https://github.com/czbiohub-sf/grassp/commit/46c0c560fa6cba3af796ae42fe44733403bac60a))
* undo accidental indent ([b4a6ba5](https://github.com/czbiohub-sf/grassp/commit/b4a6ba52d7b2a25eae2470df8e63dc24a24b605c))
* update gitignore ([3699467](https://github.com/czbiohub-sf/grassp/commit/3699467d84105319d846aaa838dbc0806498b5f0))
* xticklabels centered and refactor ([d23f6e0](https://github.com/czbiohub-sf/grassp/commit/d23f6e0fd33cca03e547fd48ec82405ce1e5d209))
